==> adalid-alfa-2.1.0-sources.jar: meta/entidad/comun/configuracion/basica/ClaseRecurso.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package meta.entidad.comun.configuracion.basica;

import adalid.core.AbstractPersistentEntity;
import adalid.core.annotations.Allocation;
import adalid.core.annotations.BusinessKey;
import adalid.core.annotations.ColumnField;
import adalid.core.annotations.DescriptionProperty;
import adalid.core.annotations.EntityClass;
import adalid.core.annotations.EntityCodeGen;
import adalid.core.annotations.EntityConsoleView;
import adalid.core.annotations.EntityDeleteOperation;
import adalid.core.annotations.EntityDetailView;
import adalid.core.annotations.EntityInsertOperation;
import adalid.core.annotations.EntitySelectOperation;
import adalid.core.annotations.EntityTableView;
import adalid.core.annotations.EntityTreeView;
import adalid.core.annotations.EntityUpdateOperation;
import adalid.core.annotations.ForeignKey;
import adalid.core.annotations.ManyToOne;
import adalid.core.annotations.NameProperty;
import adalid.core.annotations.PrimaryKey;
import adalid.core.annotations.StringField;
import adalid.core.annotations.VersionProperty;
import adalid.core.enums.Kleenean;
import adalid.core.enums.MasterDetailView;
import adalid.core.enums.Navigability;
import adalid.core.enums.OnDeleteAction;
import adalid.core.enums.OnUpdateAction;
import adalid.core.enums.OperationAccess;
import adalid.core.enums.ResourceGender;
import adalid.core.enums.ResourceType;
import adalid.core.interfaces.Artifact;
import adalid.core.properties.BooleanProperty;
import adalid.core.properties.IntegerProperty;
import adalid.core.properties.LongProperty;
import adalid.core.properties.StringProperty;
import java.lang.reflect.Field;

/**
 * @author Jorge Campins
 */
@EntityClass(catalog = Kleenean.TRUE, independent = Kleenean.TRUE, resourceType = ResourceType.CONFIGURATION, resourceGender = ResourceGender.FEMININE)
@EntityCodeGen(bws = Kleenean.FALSE, fws = Kleenean.FALSE)
@EntitySelectOperation(enabled = Kleenean.TRUE, access = OperationAccess.PUBLIC, rowsLimit = 0)
@EntityInsertOperation(enabled = Kleenean.FALSE)
@EntityUpdateOperation(enabled = Kleenean.FALSE)
@EntityDeleteOperation(enabled = Kleenean.FALSE)
@EntityTableView(enabled = Kleenean.TRUE)
@EntityDetailView(enabled = Kleenean.TRUE)
@EntityTreeView(enabled = Kleenean.FALSE)
@EntityConsoleView(enabled = Kleenean.FALSE)
public class ClaseRecurso extends AbstractPersistentEntity {

    // <editor-fold defaultstate="collapsed" desc="class constructors">
    @Deprecated
    private ClaseRecurso() {
        this(null, null);
    }

    public ClaseRecurso(Artifact declaringArtifact, Field declaringField) {
        super(declaringArtifact, declaringField);
    }
    // </editor-fold>

    @PrimaryKey
    public LongProperty id;

    @VersionProperty
    public LongProperty version;

    @BusinessKey
    @StringField(maxLength = 100)
    public StringProperty codigoClaseRecurso;

    @NameProperty
    public StringProperty nombreClaseRecurso;

    @DescriptionProperty
    public StringProperty descripcionClaseRecurso;

    @StringField(maxLength = 200)
    public StringProperty paqueteClaseRecurso;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoIndependiente;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoSinDetalle;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoConArbol;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoSegmento;

    public IntegerProperty limiteFilasConsulta;

    public IntegerProperty limiteFilasInforme;

    public IntegerProperty ordenPresentacion;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoInsertable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoModificable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoEliminable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoExtendida;

    @StringField(maxLength = 20)
    public StringProperty etiquetaHipervinculo;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esEnumeradorConNumero;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @ColumnField(nullable = Kleenean.FALSE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public TipoClaseRecurso tipoClaseRecurso;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @ColumnField(nullable = Kleenean.FALSE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public TipoRecurso tipoRecurso;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public Funcion funcionSeleccion;

    @StringField(maxLength = 100)
    public StringProperty paginaSeleccion;

    @StringField(maxLength = 100)
    public StringProperty paginaDetalle;

    @StringField(maxLength = 100)
    public StringProperty paginaFuncion;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public ClaseRecurso claseRecursoMaestro;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public ClaseRecurso claseRecursoSegmento;

    @ForeignKey(onDelete = OnDeleteAction.NONE, onUpdate = OnUpdateAction.NONE)
    @ManyToOne(navigability = Navigability.UNIDIRECTIONAL, view = MasterDetailView.NONE)
    @Allocation(maxDepth = 1, maxRound = 0)
    public ClaseRecurso claseRecursoBase;

    @Override
    protected void settleAttributes() {
        super.settleAttributes();
//      setSchema(ProyectoBase.getEsquemaEntidadesComunes());
        // <editor-fold defaultstate="collapsed" desc="localization of ClaseRecurso's attributes">
        setLocalizedLabel(ENGLISH, "resource class");
        setLocalizedLabel(SPANISH, "clase de recurso");
        setLocalizedShortLabel(ENGLISH, "class");
        setLocalizedShortLabel(SPANISH, "clase");
        setLocalizedCollectionLabel(ENGLISH, "Resource Classes");
        setLocalizedCollectionLabel(SPANISH, "Clases de Recurso");
        setLocalizedCollectionShortLabel(ENGLISH, "Classes");
        setLocalizedCollectionShortLabel(SPANISH, "Clases");
        setLocalizedDescription(ENGLISH, "persistence domain object that typically represents a table in the database");
        setLocalizedDescription(SPANISH, "objeto de dominio de persistencia que normalmente representa una tabla en la base de datos");
        // </editor-fold>
    }

    @Override
    protected void settleProperties() {
        super.settleProperties();
        esClaseRecursoIndependiente.setInitialValue(false);
        esClaseRecursoIndependiente.setDefaultValue(false);
        esClaseRecursoSinDetalle.setInitialValue(false);
        esClaseRecursoSinDetalle.setDefaultValue(false);
        esClaseRecursoConArbol.setInitialValue(false);
        esClaseRecursoConArbol.setDefaultValue(false);
        esClaseRecursoSegmento.setInitialValue(false);
        esClaseRecursoSegmento.setDefaultValue(false);
        tipoClaseRecurso.setInitialValue(tipoClaseRecurso.TABLA);
        tipoClaseRecurso.setDefaultValue(tipoClaseRecurso.TABLA);
        esClaseRecursoInsertable.setInitialValue(true);
        esClaseRecursoInsertable.setDefaultValue(true);
        esClaseRecursoModificable.setInitialValue(true);
        esClaseRecursoModificable.setDefaultValue(true);
        esClaseRecursoEliminable.setInitialValue(true);
        esClaseRecursoEliminable.setDefaultValue(true);
        esClaseRecursoExtendida.setInitialValue(false);
        esClaseRecursoExtendida.setDefaultValue(false);
        esEnumeradorConNumero.setInitialValue(false);
        esEnumeradorConNumero.setDefaultValue(false);
        // <editor-fold defaultstate="collapsed" desc="localization of ClaseRecurso's properties">
        codigoClaseRecurso.setLocalizedLabel(ENGLISH, "resource class code");
        codigoClaseRecurso.setLocalizedLabel(SPANISH, "código de la clase de recurso");
        codigoClaseRecurso.setLocalizedShortLabel(ENGLISH, "code");
        codigoClaseRecurso.setLocalizedShortLabel(SPANISH, "código");
        /**/
        nombreClaseRecurso.setLocalizedLabel(ENGLISH, "resource class name");
        nombreClaseRecurso.setLocalizedLabel(SPANISH, "nombre de la clase de recurso");
        nombreClaseRecurso.setLocalizedShortLabel(ENGLISH, "name");
        nombreClaseRecurso.setLocalizedShortLabel(SPANISH, "nombre");
        /**/
        descripcionClaseRecurso.setLocalizedLabel(ENGLISH, "resource class description");
        descripcionClaseRecurso.setLocalizedLabel(SPANISH, "descripción de la clase de recurso");
        descripcionClaseRecurso.setLocalizedShortLabel(ENGLISH, "description");
        descripcionClaseRecurso.setLocalizedShortLabel(SPANISH, "descripción");
        /**/
        paqueteClaseRecurso.setLocalizedLabel(ENGLISH, "resource class package");
        paqueteClaseRecurso.setLocalizedLabel(SPANISH, "paquete clase recurso");
        paqueteClaseRecurso.setLocalizedShortLabel(ENGLISH, "package");
        paqueteClaseRecurso.setLocalizedShortLabel(SPANISH, "paquete");
        /**/
        esClaseRecursoIndependiente.setLocalizedLabel(ENGLISH, "independent resource class");
        esClaseRecursoIndependiente.setLocalizedLabel(SPANISH, "clase recurso independiente");
        esClaseRecursoIndependiente.setLocalizedShortLabel(ENGLISH, "independent");
        esClaseRecursoIndependiente.setLocalizedShortLabel(SPANISH, "independiente");
        /**/
        esClaseRecursoSinDetalle.setLocalizedLabel(ENGLISH, "resource class without detail");
        esClaseRecursoSinDetalle.setLocalizedLabel(SPANISH, "clase recurso sin detalle");
        esClaseRecursoSinDetalle.setLocalizedShortLabel(ENGLISH, "without detail");
        esClaseRecursoSinDetalle.setLocalizedShortLabel(SPANISH, "sin detalle");
        /**/
        esClaseRecursoConArbol.setLocalizedLabel(ENGLISH, "resource class with tree");
        esClaseRecursoConArbol.setLocalizedLabel(SPANISH, "clase recurso con arbol");
        esClaseRecursoConArbol.setLocalizedShortLabel(ENGLISH, "with tree");
        esClaseRecursoConArbol.setLocalizedShortLabel(SPANISH, "con arbol");
        /**/
        esClaseRecursoSegmento.setLocalizedLabel(ENGLISH, "segment resource class");
        esClaseRecursoSegmento.setLocalizedLabel(SPANISH, "clase recurso segmento");
        esClaseRecursoSegmento.setLocalizedShortLabel(ENGLISH, "segment");
        esClaseRecursoSegmento.setLocalizedShortLabel(SPANISH, "segmento");
        /**/
        limiteFilasConsulta.setLocalizedLabel(ENGLISH, "query rows limit");
        limiteFilasConsulta.setLocalizedLabel(SPANISH, "limite filas consulta");
        /**/
        limiteFilasInforme.setLocalizedLabel(ENGLISH, "report rows limit");
        limiteFilasInforme.setLocalizedLabel(SPANISH, "limite filas informe");
        /**/
        ordenPresentacion.setLocalizedLabel(ENGLISH, "rendering order");
        ordenPresentacion.setLocalizedLabel(SPANISH, "orden presentación");
        /**/
        esClaseRecursoInsertable.setLocalizedLabel(ENGLISH, "insertable resource class");
        esClaseRecursoInsertable.setLocalizedLabel(SPANISH, "clase recurso insertable");
        esClaseRecursoInsertable.setLocalizedShortLabel(ENGLISH, "insertable");
        esClaseRecursoInsertable.setLocalizedShortLabel(SPANISH, "insertable");
        /**/
        esClaseRecursoModificable.setLocalizedLabel(ENGLISH, "updatable resource class");
        esClaseRecursoModificable.setLocalizedLabel(SPANISH, "clase recurso modificable");
        esClaseRecursoModificable.setLocalizedShortLabel(ENGLISH, "updatable");
        esClaseRecursoModificable.setLocalizedShortLabel(SPANISH, "modificable");
        /**/
        esClaseRecursoEliminable.setLocalizedLabel(ENGLISH, "deletable resource class");
        esClaseRecursoEliminable.setLocalizedLabel(SPANISH, "clase recurso eliminable");
        esClaseRecursoEliminable.setLocalizedShortLabel(ENGLISH, "deletable");
        esClaseRecursoEliminable.setLocalizedShortLabel(SPANISH, "eliminable");
        /**/
        esClaseRecursoExtendida.setLocalizedLabel(ENGLISH, "extended resource class");
        esClaseRecursoExtendida.setLocalizedLabel(SPANISH, "clase recurso extendida");
        esClaseRecursoExtendida.setLocalizedShortLabel(ENGLISH, "extended");
        esClaseRecursoExtendida.setLocalizedShortLabel(SPANISH, "extendida");
        /**/
        etiquetaHipervinculo.setLocalizedLabel(ENGLISH, "hyperlink label");
        etiquetaHipervinculo.setLocalizedLabel(SPANISH, "etiqueta hipervinculo");
        /**/
        esEnumeradorConNumero.setLocalizedLabel(ENGLISH, "enumerator with number");
        esEnumeradorConNumero.setLocalizedLabel(SPANISH, "enumerador con numero");
        /**/
        tipoClaseRecurso.setLocalizedLabel(ENGLISH, "resource class type");
        tipoClaseRecurso.setLocalizedLabel(SPANISH, "tipo de clase de recurso");
        tipoClaseRecurso.setLocalizedShortLabel(ENGLISH, "type");
        tipoClaseRecurso.setLocalizedShortLabel(SPANISH, "tipo");
        /**/
        tipoRecurso.setLocalizedLabel(ENGLISH, "resource type");
        tipoRecurso.setLocalizedLabel(SPANISH, "tipo de recurso");
        /**/
        funcionSeleccion.setLocalizedLabel(ENGLISH, "select function");
        funcionSeleccion.setLocalizedLabel(SPANISH, "función de selección");
        /**/
        paginaSeleccion.setLocalizedLabel(ENGLISH, "select page");
        paginaSeleccion.setLocalizedLabel(SPANISH, "página de selección");
        /**/
        paginaDetalle.setLocalizedLabel(ENGLISH, "detail page");
        paginaDetalle.setLocalizedLabel(SPANISH, "página de detalle");
        /**/
        paginaFuncion.setLocalizedLabel(ENGLISH, "function page");
        paginaFuncion.setLocalizedLabel(SPANISH, "página de función");
        /**/
        claseRecursoMaestro.setLocalizedLabel(ENGLISH, "master resource class");
        claseRecursoMaestro.setLocalizedLabel(SPANISH, "clase de recurso maestro");
        claseRecursoMaestro.setLocalizedShortLabel(ENGLISH, "master class");
        claseRecursoMaestro.setLocalizedShortLabel(SPANISH, "clase de maestro");
        /**/
        claseRecursoSegmento.setLocalizedLabel(ENGLISH, "segment resource class");
        claseRecursoSegmento.setLocalizedLabel(SPANISH, "clase de recurso segmento");
        claseRecursoSegmento.setLocalizedShortLabel(ENGLISH, "segment class");
        claseRecursoSegmento.setLocalizedShortLabel(SPANISH, "clase de segmento");
        /**/
        claseRecursoBase.setLocalizedLabel(ENGLISH, "base resource class");
        claseRecursoBase.setLocalizedLabel(SPANISH, "clase de recurso base");
        claseRecursoBase.setLocalizedShortLabel(ENGLISH, "base class");
        claseRecursoBase.setLocalizedShortLabel(SPANISH, "clase base");
        // </editor-fold>
    }

}

==> adalid-alfa-4.3.0-sources.jar: meta/entidad/comun/configuracion/basica/ClaseRecurso.java <==
/*
 * Copyright 2017 Jorge Campins y David Uzcategui
 *
 * Este archivo forma parte de Adalid.
 *
 * Adalid es software libre; usted puede redistribuirlo y/o modificarlo bajo los terminos de la
 * licencia "GNU General Public License" publicada por la Fundacion "Free Software Foundation".
 * Adalid se distribuye con la esperanza de que pueda ser util, pero SIN NINGUNA GARANTIA; sin
 * siquiera las garantias implicitas de COMERCIALIZACION e IDONEIDAD PARA UN PROPOSITO PARTICULAR.
 *
 * Para mas detalles vea la licencia "GNU General Public License" en http://www.gnu.org/licenses
 */
package meta.entidad.comun.configuracion.basica;

import adalid.core.*;
import adalid.core.annotations.*;
import adalid.core.enums.*;
import adalid.core.interfaces.*;
import adalid.core.properties.*;
import java.lang.reflect.Field;

/**
 * @author Jorge Campins
 */
@EntityClass(catalog = Kleenean.TRUE, independent = Kleenean.TRUE, resourceType = ResourceType.CONFIGURATION, resourceGender = ResourceGender.FEMININE)
@EntityCodeGen(bws = Kleenean.FALSE, fws = Kleenean.FALSE)
@EntitySelectOperation(enabled = Kleenean.TRUE, access = OperationAccess.PUBLIC, rowsLimit = 0)
@EntityInsertOperation(enabled = Kleenean.FALSE)
@EntityUpdateOperation(enabled = Kleenean.FALSE)
@EntityDeleteOperation(enabled = Kleenean.FALSE)
@EntityTableView(enabled = Kleenean.TRUE)
@EntityDetailView(enabled = Kleenean.TRUE)
@EntityTreeView(enabled = Kleenean.FALSE)
@EntityConsoleView(enabled = Kleenean.FALSE)
public class ClaseRecurso extends AbstractPersistentEntity {

    // <editor-fold defaultstate="collapsed" desc="class constructors">
    public ClaseRecurso(Artifact declaringArtifact, Field declaringField) {
        super(declaringArtifact, declaringField);
    }
    // </editor-fold>

    @PrimaryKey
    public LongProperty id;

    @VersionProperty
    public LongProperty version;

    @BusinessKey
    @StringField(maxLength = 100)
    public StringProperty codigoClaseRecurso;

    @NameProperty
    public StringProperty nombreClaseRecurso;

    @DescriptionProperty
    public StringProperty descripcionClaseRecurso;

    @StringField(maxLength = 200)
    public StringProperty paqueteClaseRecurso;

    @StringField(maxLength = 200)
    public StringProperty claseJavaClaseRecurso;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoIndependiente;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoSinDetalle;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoConArbol;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoSegmento;

    public IntegerProperty limiteFilasConsulta;

    public IntegerProperty limiteFilasInforme;

    public IntegerProperty ordenPresentacion;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoInsertable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoModificable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoEliminable;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esClaseRecursoExtendida;

    @StringField(maxLength = 20)
    public StringProperty etiquetaHipervinculo;

    @ColumnField(nullable = Kleenean.FALSE)
    public BooleanProperty esEnumeradorConNumero;

    @Override
    protected void settleAttributes() {
        super.settleAttributes();
        setOrderBy(codigoClaseRecurso);
//      setSchema(ProyectoBase.getEsquemaEntidadesComunes());
        // <editor-fold defaultstate="collapsed" desc="localization of ClaseRecurso's attributes">
        setLocalizedLabel(ENGLISH, "resource class");
        setLocalizedLabel(SPANISH, "clase de recurso");
        setLocalizedShortLabel(ENGLISH, "class");
        setLocalizedShortLabel(SPANISH, "clase");
        setLocalizedCollectionLabel(ENGLISH, "Resource Classes");
        setLocalizedCollectionLabel(SPANISH, "Clases de Recurso");
        setLocalizedCollectionShortLabel(ENGLISH, "Classes");
        setLocalizedCollectionShortLabel(SPANISH, "Clases");
        setLocalizedDescription(ENGLISH, "persistence domain object that typically represents a table in the database");
        setLocalizedDescription(SPANISH, "objeto de dominio de persistencia que normalmente representa una tabla en la base de datos");
        // </editor-fold>
    }

    @Override
    protected void settleProperties() {
        super.settleProperties();
        /**/
        esClaseRecursoIndependiente.setInitialValue(false);
        esClaseRecursoIndependiente.setDefaultValue(false);
        esClaseRecursoSinDetalle.setInitialValue(false);
        esClaseRecursoSinDetalle.setDefaultValue(false);
        esClaseRecursoConArbol.setInitialValue(false);
        esClaseRecursoConArbol.setDefaultValue(false);
        esClaseRecursoSegmento.setInitialValue(false);
        esClaseRecursoSegmento.setDefaultValue(false);
        esClaseRecursoInsertable.setInitialValue(true);
        esClaseRecursoInsertable.setDefaultValue(true);
        esClaseRecursoModificable.setInitialValue(true);
        esClaseRecursoModificable.setDefaultValue(true);
        esClaseRecursoEliminable.setInitialValue(true);
        esClaseRecursoEliminable.setDefaultValue(true);
        esClaseRecursoExtendida.setInitialValue(false);
        esClaseRecursoExtendida.setDefaultValue(false);
        esEnumeradorConNumero.setInitialValue(false);
        esEnumeradorConNumero.setDefaultValue(false);
        /**/
        // <editor-fold defaultstate="collapsed" desc="localization of ClaseRecurso's properties">
        /**/
        codigoClaseRecurso.setLocalizedLabel(ENGLISH, "resource class code");
        codigoClaseRecurso.setLocalizedLabel(SPANISH, "código de la clase de recurso");
        codigoClaseRecurso.setLocalizedShortLabel(ENGLISH, "code");
        codigoClaseRecurso.setLocalizedShortLabel(SPANISH, "código");
        /**/
        nombreClaseRecurso.setLocalizedLabel(ENGLISH, "resource class name");
        nombreClaseRecurso.setLocalizedLabel(SPANISH, "nombre de la clase de recurso");
        nombreClaseRecurso.setLocalizedShortLabel(ENGLISH, "name");
        nombreClaseRecurso.setLocalizedShortLabel(SPANISH, "nombre");
        /**/
        descripcionClaseRecurso.setLocalizedLabel(ENGLISH, "resource class description");
        descripcionClaseRecurso.setLocalizedLabel(SPANISH, "descripción de la clase de recurso");
        descripcionClaseRecurso.setLocalizedShortLabel(ENGLISH, "description");
        descripcionClaseRecurso.setLocalizedShortLabel(SPANISH, "descripción");
        /**/
        paqueteClaseRecurso.setLocalizedLabel(ENGLISH, "resource class package");
        paqueteClaseRecurso.setLocalizedLabel(SPANISH, "paquete clase recurso");
        paqueteClaseRecurso.setLocalizedShortLabel(ENGLISH, "package");
        paqueteClaseRecurso.setLocalizedShortLabel(SPANISH, "paquete");
        /**/
        esClaseRecursoIndependiente.setLocalizedLabel(ENGLISH, "independent resource class");
        esClaseRecursoIndependiente.setLocalizedLabel(SPANISH, "clase recurso independiente");
        esClaseRecursoIndependiente.setLocalizedShortLabel(ENGLISH, "independent");
        esClaseRecursoIndependiente.setLocalizedShortLabel(SPANISH, "independiente");
        /**/
        esClaseRecursoSinDetalle.setLocalizedLabel(ENGLISH, "resource class without detail");
        esClaseRecursoSinDetalle.setLocalizedLabel(SPANISH, "clase recurso sin detalle");
        esClaseRecursoSinDetalle.setLocalizedShortLabel(ENGLISH, "without detail");
        esClaseRecursoSinDetalle.setLocalizedShortLabel(SPANISH, "sin detalle");
        /**/
        esClaseRecursoConArbol.setLocalizedLabel(ENGLISH, "resource class with tree");
        esClaseRecursoConArbol.setLocalizedLabel(SPANISH, "clase recurso con arbol");
        esClaseRecursoConArbol.setLocalizedShortLabel(ENGLISH, "with tree");
        esClaseRecursoConArbol.setLocalizedShortLabel(SPANISH, "con arbol");
        /**/
        esClaseRecursoSegmento.setLocalizedLabel(ENGLISH, "segment resource class");
        esClaseRecursoSegmento.setLocalizedLabel(SPANISH, "clase recurso segmento");
        esClaseRecursoSegmento.setLocalizedShortLabel(ENGLISH, "segment");
        esClaseRecursoSegmento.setLocalizedShortLabel(SPANISH, "segmento");
        /**/
        limiteFilasConsulta.setLocalizedLabel(ENGLISH, "query rows limit");
        limiteFilasConsulta.setLocalizedLabel(SPANISH, "limite filas consulta");
        /**/
        limiteFilasInforme.setLocalizedLabel(ENGLISH, "report rows limit");
        limiteFilasInforme.setLocalizedLabel(SPANISH, "limite filas informe");
        /**/
        ordenPresentacion.setLocalizedLabel(ENGLISH, "rendering order");
        ordenPresentacion.setLocalizedLabel(SPANISH, "orden presentación");
        /**/
        esClaseRecursoInsertable.setLocalizedLabel(ENGLISH, "insertable resource class");
        esClaseRecursoInsertable.setLocalizedLabel(SPANISH, "clase recurso insertable");
        esClaseRecursoInsertable.setLocalizedShortLabel(ENGLISH, "insertable");
        esClaseRecursoInsertable.setLocalizedShortLabel(SPANISH, "insertable");
        /**/
        esClaseRecursoModificable.setLocalizedLabel(ENGLISH, "updatable resource class");
        esClaseRecursoModificable.setLocalizedLabel(SPANISH, "clase recurso modificable");
        esClaseRecursoModificable.setLocalizedShortLabel(ENGLISH, "updatable");
        esClaseRecursoModificable.setLocalizedShortLabel(SPANISH, "modificable");
        /**/
        esClaseRecursoEliminable.setLocalizedLabel(ENGLISH, "deletable resource class");
        esClaseRecursoEliminable.setLocalizedLabel(SPANISH, "clase recurso eliminable");
        esClaseRecursoEliminable.setLocalizedShortLabel(ENGLISH, "deletable");
        esClaseRecursoEliminable.setLocalizedShortLabel(SPANISH, "eliminable");
        /**/
        esClaseRecursoExtendida.setLocalizedLabel(ENGLISH, "extended resource class");
        esClaseRecursoExtendida.setLocalizedLabel(SPANISH, "clase recurso extendida");
        esClaseRecursoExtendida.setLocalizedShortLabel(ENGLISH, "extended");
        esClaseRecursoExtendida.setLocalizedShortLabel(SPANISH, "extendida");
        /**/
        etiquetaHipervinculo.setLocalizedLabel(ENGLISH, "hyperlink label");
        etiquetaHipervinculo.setLocalizedLabel(SPANISH, "etiqueta hipervinculo");
        /**/
        esEnumeradorConNumero.setLocalizedLabel(ENGLISH, "enumerator with number");
        esEnumeradorConNumero.setLocalizedLabel(SPANISH, "enumerador con número");
        /**/
        // </editor-fold>
    }

}
